@@ -59,7 +59,7 @@ class SyntheticImage:
             data_type: Rasterio datatype as string.
             out_dir: Path where the image should be created (default ".").
             coord_ref_sys: EPSG identifier of used coordinate reference system (default 3837).
-            nodata: Value representing nodata within each raster band, default is 0.
+            nodata: Value representing nodata within each raster band, default is 0. If set to -1 no nodata value set.
             nodata_fill: number of no data pixels to set in top left image (in x and y).
 
         Example:
@@ -76,8 +76,11 @@ class SyntheticImage:
         self.data_type = data_type
         self.out_dir = out_dir
         self.crs = coord_ref_sys
-        self.nodata = nodata
         self.nodata_fill = nodata_fill
+        if nodata == -1:
+            self.nodata = None
+        else:
+            self.nodata = nodata
 
     def add_img_pattern(self, seed: Optional[int]) -> np.ndarray:
         """
@@ -158,6 +161,12 @@ class SyntheticImage:
         else:
             filepath = self.out_dir.joinpath(file_name + ".tif")
 
+        # Even though we don't want a nodata value to be set, we still need a value that represents it for image
+        # creation purposes
+        if self.nodata is None:
+            nodata_val = 0
+        else:
+            nodata_val = self.nodata
         with rasterio.open(
             filepath,
             "w",
@@ -171,7 +180,7 @@ class SyntheticImage:
             nodata=self.nodata,
         ) as out_img:
             for band_id, layer in enumerate(band_list):
-                layer[0 : self.nodata_fill, 0 : self.nodata_fill] = self.nodata
+                layer[0 : self.nodata_fill, 0 : self.nodata_fill] = nodata_val
                 out_img.write_band(band_id + 1, layer)
                 if band_desc is not None:
                     try:
